@@ -1,7 +1,7 @@
 #
-# $HeadURL: https://svn.oucs.ox.ac.uk/networks/src/debian/packages/libr/librpc-serialized-perl/trunk/lib/RPC/Serialized.pm $
+# $HeadURL: https://svn.oucs.ox.ac.uk/people/oliver/pub/librpc-serialized-perl/trunk/lib/RPC/Serialized.pm $
 # $LastChangedRevision: 1637 $
-# $LastChangedDate: 2008-03-31 13:34:26 +0100 (Mon, 31 Mar 2008) $
+# $LastChangedDate: 2008-10-01 16:16:56 +0100 (Wed, 01 Oct 2008) $
 # $LastChangedBy: oliver $
 #
 package RPC::Serialized;
@@ -16,7 +16,7 @@ use Data::Serializer;
 use RPC::Serialized::Config;
 use RPC::Serialized::Exceptions;
 
-our $VERSION = '0.0605';
+our $VERSION = '0.0701';
 
 __PACKAGE__->mk_ro_accessors(qw/
     debug
@@ -118,7 +118,7 @@ sub recv {
         if $io->error;
 
     chomp $data if defined $data;
-    return undef unless length($data);
+    return unless defined($data) && length($data);
 
     my @token = ();
     eval {
@@ -162,7 +162,7 @@ RPC::Serialized - Subroutine calls over the network using common serialization
 
 =head1 VERSION
 
-This document refers to version 0.0605 of RPC::Serialized
+This document refers to version 0.0701 of RPC::Serialized
 
 =head1 SYNOPSIS
 
